# :syringe: pyvitemadose

pyvitemadose displays available schedule of covid vaccine for your departement in France
# 💫 Demo

![demo_vitemadose](https://user-images.githubusercontent.com/45128847/137623852-d8e32778-cff4-4849-9a0c-af430aa78e75.gif)

# 🚀 How to use **pyvitemadose**

pyvitemadose \[DPT\] with DPT the department

example : ``pyvitemadose 75`` to display available schedule availables in dpt 75

## Other options

  - ``-b/--before [DATE]``  filter schedule before the date given (yyyy-mm-dd format)
  - ``-h/--help``    show the help message and exit
  - ``-u/--update``  update pyvitemadose

# ⚙️ Install

See [this page](INSTALL.md)
# :construction_worker: Contribution

See [this page](CONTRIBUTING.md)

# :package: Changelog

See [this page](CHANGELOG.md)
# License

MIT License

Copyright (c) 2021 [thib1984](https://github.com/thib1984)

See [this page](LICENSE.txt) for details